@@ -352,7 +352,9 @@ def convert_bip32_strpath_to_intpath(n: str) -> List[int]:
     return path
 
 
-def convert_bip32_intpath_to_strpath(path: Sequence[int]) -> str:
+def convert_bip32_intpath_to_strpath(path: Sequence[int], *, hardened_char=BIP32_HARDENED_CHAR) -> str:
+    assert isinstance(hardened_char, str), hardened_char
+    assert len(hardened_char) == 1, hardened_char
     s = "m/"
     for child_index in path:
         if not isinstance(child_index, int):
@@ -361,7 +363,7 @@ def convert_bip32_intpath_to_strpath(path: Sequence[int]) -> str:
             raise ValueError(f"bip32 path child index out of range: {child_index}")
         prime = ""
         if child_index & BIP32_PRIME:
-            prime = BIP32_HARDENED_CHAR
+            prime = hardened_char
             child_index = child_index ^ BIP32_PRIME
         s += str(child_index) + prime + '/'
     # cut trailing "/"
@@ -380,13 +382,13 @@ def is_bip32_derivation(s: str) -> bool:
         return True
 
 
-def normalize_bip32_derivation(s: Optional[str]) -> Optional[str]:
+def normalize_bip32_derivation(s: Optional[str], *, hardened_char=BIP32_HARDENED_CHAR) -> Optional[str]:
     if s is None:
         return None
     if not is_bip32_derivation(s):
         raise ValueError(f"invalid bip32 derivation: {s}")
     ints = convert_bip32_strpath_to_intpath(s)
-    return convert_bip32_intpath_to_strpath(ints)
+    return convert_bip32_intpath_to_strpath(ints, hardened_char=hardened_char)
 
 
 def is_all_public_derivation(path: Union[str, Iterable[int]]) -> bool:
